@@ -1,23 +1,26 @@
-from django.core.management.base import BaseCommand, CommandError
-from django.apps import apps
-from elasticsearch_dsl.connections import connections
-from elasticsearch.helpers import bulk
-from optparse import make_option
-from seeker.registry import model_doc_types
 import json
+from optparse import make_option
 
-class Command (BaseCommand):
+from django.apps import apps
+from django.core.management.base import BaseCommand, CommandError
+from elasticsearch.helpers import bulk
+from elasticsearch_dsl.connections import connections
+
+from seeker.registry import model_doc_types
+
+
+class Command(BaseCommand):
     args = '<app1 app2 ...>'
     option_list = BaseCommand.option_list + (
         make_option('--filename', '-f',
-            dest='filename',
-            default=None,
-            help='The file to load index data from'
+                    dest='filename',
+                    default=None,
+                    help='The file to load index data from',
         ),
         make_option('--index',
-            dest='index',
-            default=None,
-            help='Index to load data into'
+                    dest='index',
+                    default=None,
+                    help='Index to load data into',
         ),
     )
 
